import { h } from 'vue'
import axios, { AxiosError } from 'axios'
import { ElMessage } from 'element-plus'
import { setupAuthSign, transformRequestData } from '@/plugins/request/plugin'
import { filterEmpty, downloadBlob, extractFileName } from '@/utils/common'
import { logout } from '@/utils/shared'

const request = axios.create({
  baseURL: import.meta.env.VITE_APP_API_HOST || '/',
  withCredentials: true,
  timeout: 20000,
  method: 'post',
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  },
})

request.interceptors.request.use(
  (config) => {
    if (!config.url) {
      throw new AxiosError('request must should a url parameter', 'REQUEST_PARAMETER_ERROR', config)
    }
    config.data = filterEmpty(config.data)
    config.params = filterEmpty(config.params)

    setupAuthSign(config)
    transformRequestData(config)

    if (config.download) {
      config.responseType ??= 'blob'
    }
    return config
  },
  (error: AxiosError) => {
    if (!error.config.noToast) {
      ElMessage.error(error.message || error.name || error.code)
    }
    return Promise.reject(error)
  }
)

request.interceptors.response.use(
  (response) => {
    if (response.data.hasError) {
      const errMsg = response.data?.failRecords.map((v: any) => [v.msg, v.lineNum].join('--'))?.join('\n')
      ElMessage.error(errMsg)
      return Promise.reject(response.data)
    }
    if (response.config.download && response.config.responseType === 'blob') {
      downloadBlob(response.data, extractFileName(response.headers?.['content-disposition'] as string))
    }
    return response.data
  },
  async (error: AxiosError<any>) => {
    if (!error.config?.noToast && error?.code !== 'ERR_CANCELED') {
      if (error.isAxiosError) {
        if (
          error.response &&
          ([401, 403].includes(error.response.status) || error.response.data?.code?.toString()?.startsWith('401'))
        ) {
          logout()
          ElMessage.error({ message: '登录状态已过期', key: 'token-valid' })
          return Promise.reject(error)
        }
        let msg = ''
        if (error.config?.responseType === 'blob') {
          try {
            const e = JSON.parse(await error?.response?.data?.text())
            msg = e.message || e.error || e
          } catch (error) {
            console.error(error)
          }
        }
        if (!msg) {
          msg = error?.response?.data?.message || error.message || error.code || error.name
        }
        msg && ElMessage.error(msg)
      } else {
        error.message && ElMessage.error(error.message)
      }
    }
    // if (error.response?.data) {
    //   return Promise.reject(error.response.data)
    // }
    return Promise.reject(error)
  }
)

export default request
