import { SHA1, enc } from 'crypto-js'
import { sessionStorage } from '@/plugins/storage'
import type { Method, AxiosRequestConfig } from 'axios'
import type { ExtractApiResponse } from 'api-type'

interface SignTokenParams {
  url?: string
  method?: Method | string
  sessionId: string
  accessToken: string
}

/**
 * @description Http请求签名
 */
export const signToken = ({ sessionId, accessToken, url = '/', method = 'post' }: SignTokenParams) => {
  const timestamp = Date.now()
  const token = `Token ${sessionId}:${enc.Base64.stringify(
    SHA1(`${method?.toLowerCase() || 'post'}&${url}&${timestamp}&${accessToken}`)
  )}`
  return { token, timestamp }
}

/**
 * @description 设置Http请求签名信息
 */
export const setupAuthSign = (config: AxiosRequestConfig) => {
  config.headers = config.headers || {}
  if (!config.noAuth) {
    const { sessionId, accessToken } = (sessionStorage.get('LOGIN_RESULT') as ExtractApiResponse<'userLogin'>) || {}
    const { token, timestamp } = signToken({
      url: config.url,
      method: config.method,
      sessionId: sessionId,
      accessToken: accessToken,
    })
    config.headers['Authorization'] = token
    config.headers['time'] = timestamp
  }
  return config
}

/**
 * @description 除了文件上传以外, 其它默认使用表单形式提交数据
 */
export const transformRequestData = (config: AxiosRequestConfig) => {
  config.headers = config.headers || {}
  if (config.headers['Content-Type']?.toString().includes('application/x-www-form-urlencoded')) {
    config.data = new URLSearchParams(config.data)
  }
  return config
}
